<h1 align="center">wtday
</h1>
<p align="center"><img src="https://img.shields.io/badge/Python-blue?style=for-the-badge&logo=python&logoColor=FFD43B"></p>

A command-line tool to find out what's celebrated today in seconds

### Getting Started

Install it

```sh
pip install wtday
```

Then use it

```sh
wtday
```

You should get something like:

![image](https://user-images.githubusercontent.com/65634520/218370196-8d183ec6-a2a6-436d-a319-ae1beb90045a.png)